#!/usr/bin/env python3
import os
import csv
import datetime
import collections

confirmed = csv.reader(open("time_series_covid19_confirmed_global.csv", "r"))
dead = csv.reader(open("time_series_covid19_deaths_global.csv", "r"))
recovered = csv.reader(open("time_series_covid19_recovered_global.csv", "r"))

# Province/State,Country/Region,Lat,Long,1/22/20,1/23/20,1/24/20,1/25/20,1/26/20,1/27/20,1/28/20,1/29/20,1/30/20,1/31/20,2/1/20,2/2/20,2/3/20,2/4/20,2/5/20,2/6/20,2/7/20,2/8/20,2/9/20,2/10/20,2/11/20,2/12/20,2/13/20,2/14/20,2/15/20,2/16/20,2/17/20,2/18/20,2/19/20,2/20/20,2/21/20,2/22/20,2/23/20,2/24/20,2/25/20,2/26/20,2/27/20,2/28/20,2/29/20,3/1/20,3/2/20,3/3/20,3/4/20,3/5/20,3/6/20,3/7/20,3/8/20,3/9/20,3/10/20,3/11/20,3/12/20,3/13/20,3/14/20,3/15/20,3/16/20,3/17/20,3/18/20,3/19/20,3/20/20,3/21/20,3/22/20,3/23/20,3/24/20,3/25/20

def calc_totals(c):
    header = next(c)
    totals = collections.OrderedDict()
    for d in header[4:]:
        totals[d] = 0

    for line in c:
        as_dict = dict(zip(header[4:], line[4:]))
        for k,v in as_dict.items():
            totals[k] += int(v)
    return totals

confirmed = calc_totals(confirmed)
dead = calc_totals(dead)
recovered = calc_totals(recovered)

print("DAILY CHANGE - LAST 5 DAYS")
for k in list(confirmed.keys())[-5:]:
    print(f"{k}    ", end="")
print()
print()

print("\t\tCONFIRMED")
prev = list(confirmed.values())[-6]
for v in list(confirmed.values())[-5:]:
    print(f"{v-prev}\t", end="")
    prev = v
print()

print("\t\tDEAD")
prev = list(dead.values())[-6]
for v in list(dead.values())[-5:]:
    print(f"{v-prev}\t", end="")
    prev = v
print()

print("\t\tRECOVERED")
prev = list(recovered.values())[-6]
for v in list(recovered.values())[-5:]:
    print(f"{v-prev}\t", end="")
    prev = v
print()
